package com.ruoyi.tcZz.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.tcZz.domain.TcWljgtj;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.tcZz.mapper.TcWpwzlyqkMapper;
import com.ruoyi.tcZz.domain.TcWpwzlyqk;
import com.ruoyi.tcZz.service.ITcWpwzlyqkService;

/**
 * 网评文章录用情况Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
@Service
public class TcWpwzlyqkServiceImpl implements ITcWpwzlyqkService 
{
    @Autowired
    private TcWpwzlyqkMapper tcWpwzlyqkMapper;

    /**
     * 查询网评文章录用情况
     * 
     * @param id 网评文章录用情况主键
     * @return 网评文章录用情况
     */
    @Override
    public TcWpwzlyqk selectTcWpwzlyqkById(Long id)
    {
        return tcWpwzlyqkMapper.selectTcWpwzlyqkById(id);
    }

    /**
     * 查询网评文章录用情况列表
     * 
     * @param tcWpwzlyqk 网评文章录用情况
     * @return 网评文章录用情况
     */
    @Override
    public List<TcWpwzlyqk> selectTcWpwzlyqkList(TcWpwzlyqk tcWpwzlyqk)
    {
        return tcWpwzlyqkMapper.selectTcWpwzlyqkList(tcWpwzlyqk);
    }

    /**
     * 新增网评文章录用情况
     * 
     * @param tcWpwzlyqk 网评文章录用情况
     * @return 结果
     */
    @Override
    public int insertTcWpwzlyqk(TcWpwzlyqk tcWpwzlyqk)
    {
        tcWpwzlyqk.setCreateTime(DateUtils.getNowDate());
        return tcWpwzlyqkMapper.insertTcWpwzlyqk(tcWpwzlyqk);
    }

    /**
     * 修改网评文章录用情况
     * 
     * @param tcWpwzlyqk 网评文章录用情况
     * @return 结果
     */
    @Override
    public int updateTcWpwzlyqk(TcWpwzlyqk tcWpwzlyqk)
    {
        tcWpwzlyqk.setUpdateTime(DateUtils.getNowDate());
        return tcWpwzlyqkMapper.updateTcWpwzlyqk(tcWpwzlyqk);
    }

    /**
     * 批量删除网评文章录用情况
     * 
     * @param ids 需要删除的网评文章录用情况主键
     * @return 结果
     */
    @Override
    public int deleteTcWpwzlyqkByIds(Long[] ids)
    {
        return tcWpwzlyqkMapper.deleteTcWpwzlyqkByIds(ids);
    }

    /**
     * 删除网评文章录用情况信息
     * 
     * @param id 网评文章录用情况主键
     * @return 结果
     */
    @Override
    public int deleteTcWpwzlyqkById(Long id)
    {
        return tcWpwzlyqkMapper.deleteTcWpwzlyqkById(id);
    }

    @Override
    public String importUser(List<TcWpwzlyqk> tcWpwzlyqkList) {

        StringBuilder successMsg = new StringBuilder();
        if (!tcWpwzlyqkList.isEmpty()) {
            for (TcWpwzlyqk tcWpwzlyqk : tcWpwzlyqkList) {
                tcWpwzlyqkMapper.insertTcWpwzlyqk(tcWpwzlyqk);
            }
            successMsg.append("导入成功");
        }
        return successMsg.toString();

    }

    @Override
    public void updateByisStatus(Integer isStatus,List<String> ids) {
        tcWpwzlyqkMapper.updateByisStatus(isStatus,ids);
    }
}
