package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.tcZz.domain.TcWljgtj;
import com.ruoyi.tcZz.domain.TcWlwmzyz;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcWpwzlyqk;
import com.ruoyi.tcZz.service.ITcWpwzlyqkService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 网评文章录用情况Controller
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@Api(tags = "网评文章录用情况")
@RequestMapping("/tcZz/networkEcology/wpwzlyqk")
public class TcWpwzlyqkController extends BaseController {
    @Autowired
    private ITcWpwzlyqkService tcWpwzlyqkService;

    /**
     * 查询网评文章录用情况列表
     */
    @ApiOperation(value = "查询网评文章录用情况列表", response = TcWpwzlyqk.class)
    @GetMapping("/list")
    public TableDataInfo list(TcWpwzlyqk tcWpwzlyqk) {
        startPage();
        List<TcWpwzlyqk> list = tcWpwzlyqkService.selectTcWpwzlyqkList(tcWpwzlyqk);
        return getDataTable(list);
    }

    /**
     * 导出网评文章录用情况列表
     */
    @ApiOperation(value = "导出网评文章录用情况列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcWpwzlyqk tcWpwzlyqk) {
        List<TcWpwzlyqk> list = tcWpwzlyqkService.selectTcWpwzlyqkList(tcWpwzlyqk);
        ExcelUtil<TcWpwzlyqk> util = new ExcelUtil<TcWpwzlyqk>(TcWpwzlyqk.class);
        util.exportExcel(response, list, "网评文章录用情况数据");
    }

    /**
     * 获取网评文章录用情况详细信息
     */
    @ApiOperation(value = "获取网评文章录用情况详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcWpwzlyqkService.selectTcWpwzlyqkById(id));
    }

    /**
     * 新增网评文章录用情况
     */
    @ApiOperation(value = "新增网评文章录用情况")
    @PostMapping
    public AjaxResult add(@RequestBody TcWpwzlyqk tcWpwzlyqk) {
        return toAjax(tcWpwzlyqkService.insertTcWpwzlyqk(tcWpwzlyqk));
    }

    /**
     * 修改网评文章录用情况
     */
    @ApiOperation(value = "修改网评文章录用情况")
    @PutMapping
    public AjaxResult edit(@RequestBody TcWpwzlyqk tcWpwzlyqk) {
        return toAjax(tcWpwzlyqkService.updateTcWpwzlyqk(tcWpwzlyqk));
    }

    /**
     * 删除网评文章录用情况
     */
    @ApiOperation(value = "删除网评文章录用情况")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcWpwzlyqkService.deleteTcWpwzlyqkByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcWpwzlyqk> util = new ExcelUtil<TcWpwzlyqk>(TcWpwzlyqk.class);
        List<TcWpwzlyqk> tcWpwzlyqkList = util.importExcel(file.getInputStream());
        tcWpwzlyqkService.importUser(tcWpwzlyqkList);
        return AjaxResult.success();
    }
    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcWpwzlyqkService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcWpwzlyqk> util = new ExcelUtil<TcWpwzlyqk>(TcWpwzlyqk.class);
        util.importTemplateExcel(response, " 网评文章录用情况");
    }
}
